# Homepage Dashboard: Your Central Hub

Homepage is your personal, customizable application dashboard. Within Changemaker V5, it acts as the central command center, providing a unified interface to access all integrated services, monitor their status, and keep bookmarks for frequently used internal and external pages.

## Key Features

*   **Unified Access**: Quickly launch any Changemaker application (Code Server, Flatnotes, Listmonk, NocoDB, etc.) from one place.
*   **Service Status Monitoring**: (If configured) See at a glance if your services are online and operational.
*   **Customizable Layout**: Organize your dashboard with groups, links, and widgets to fit your workflow.
*   **Bookmarks**: Keep important links (both internal Changemaker services and external websites) readily accessible.
*   **Themeable**: Customize the look and feel to your preference.
*   **Lightweight & Fast**: Loads quickly and efficiently.

## Getting Started with Homepage

### Accessing Homepage
1.  **URL**: You can typically access Homepage locally via `http://localhost:3010/` (or your configured external URL if set up).
2.  **No Login Required (Usually)**: By default, Homepage itself doesn't require a login, but the services it links to (like Code Server or Listmonk) will have their own authentication.

### Basic Usage

1.  **Exploring the Dashboard**:
    *   The main view will show configured service groups and individual service links.
    *   Clicking on a service link (e.g., "Code Server") will open that application in a new tab or the current window, depending on its configuration.

2.  **Understanding the Default Configuration**:
    *   Changemaker V5 comes with a pre-configured `settings.yaml`, `services.yaml`, and potentially `bookmarks.yaml` for Homepage, located in the `configs/homepage/` directory within your Changemaker project structure.
    *   These files define what you see on your dashboard.

3.  **Customizing Your Dashboard (Advanced)**:
    *   To customize Homepage, you'll typically edit its YAML configuration files. This can be done using Code Server.
    *   **Navigate to Configuration**: In Code Server, open your Changemaker project folder, then navigate to `configs/homepage/`.
    *   **Edit `services.yaml`**: To add, remove, or modify the services displayed.
        *Example: Adding a new service*
        ```yaml
        # In services.yaml
        - My Services:
          - My New App:
              href: http://localhost:XXXX # URL of your new app
              description: Description of my new app
              icon: fas fa-rocket # Font Awesome icon
        ```
    *   **Edit `bookmarks.yaml`**: To add your own bookmarks, organized into groups.
        *Example: Adding a bookmark group*
        ```yaml
        # In bookmarks.yaml
        - Development:
          - GitHub:
              href: https://github.com/
              icon: fab fa-github
        ```
    *   **Edit `settings.yaml`**: For general settings like page title, background, etc.
    *   **Edit `widgets.yaml`**: To add dynamic information like weather, search bars, etc.
    *   **Apply Changes**: After saving changes to these YAML files, you usually need to restart the Homepage Docker container for them to take effect, or Homepage might pick them up automatically depending on its setup.

## Further Information

For more detailed information on configuring Homepage, available widgets, and advanced customization options, please refer to the [official Homepage Documentation](https://gethomepage.dev/latest/).
