# OpenWebUI: Chat Interface for Ollama

OpenWebUI provides a user-friendly, web-based chat interface for interacting with local AI models run by Ollama. It makes leveraging the power of large language models (LLMs) accessible to users who may not be comfortable with command-line interfaces, offering a familiar chat experience.

## Key Features

*   **Chat Interface**: Intuitive, ChatGPT-like interface for interacting with Ollama models.
*   **Model Selection**: Easily switch between different AI models you have downloaded via Ollama.
*   **Conversation History**: Keeps track of your chats.
*   **Responsive Design**: Usable on various devices.
*   **Self-Hosted**: Runs locally as part of your Changemaker suite, ensuring data privacy.
*   **Markdown Support**: Renders model responses that include Markdown for better formatting.

## Documentation

For more detailed information about OpenWebUI, visit the [official documentation](https://docs.openwebui.com/).

## Getting Started with OpenWebUI

### Prerequisites
*   **Ollama Must Be Running**: OpenWebUI is an interface *for* Ollama. Ensure your Ollama service is running and you have downloaded some models (e.g., `ollama pull llama3`).

### Accessing OpenWebUI
1.  **URL**: Access OpenWebUI locally via `http://localhost:3005/` (or your configured external URL).
2.  **Account Creation (First Time)**: The first time you access OpenWebUI, you'll likely need to sign up or create an admin account for the interface itself.

### Basic Usage

1.  **Log In**: Sign in with your OpenWebUI credentials.
2.  **Select a Model**: 
    *   There should be an option (often a dropdown menu) to select which Ollama model you want to chat with. This list will populate based on the models you have pulled using the Ollama service.
    *   If you don't see any models, you may need to go to a terminal (e.g., in Code Server or directly on your server) and run `ollama list` to see available models or `ollama pull <modelname>` (e.g., `ollama pull gemma:2b`) to download a new one.
3.  **Start Chatting**: 
    *   Type your prompt or question into the message box at the bottom of the screen and press Enter or click the send button.
    *   The selected Ollama model will process your input and generate a response, which will appear in the chat window.
4.  **Manage Conversations**: You can typically start new chats or revisit previous conversations from a sidebar.

## Use Cases within Changemaker

*   **Content Generation**: Draft blog posts, newsletter content, social media updates, or documentation.
*   **Brainstorming**: Generate ideas for campaigns, projects, or problem-solving.
*   **Research Assistance**: Ask questions and get summaries on various topics (ensure you verify information from LLMs).
*   **Drafting Responses**: Help formulate replies to emails or messages.
*   **Learning & Exploration**: Experiment with different AI models and their capabilities.

## Editing the Site

OpenWebUI is a tool for interacting with AI models. It is not used for editing this documentation site. Site editing is done via **Code Server**.

## Further Information

*   **OpenWebUI Official Documentation/GitHub**: [https://docs.openwebui.com/](https://docs.openwebui.com/) or their GitHub repository (often linked from the UI itself).
*   **Ollama Documentation**: [https://ollama.ai/docs](https://ollama.ai/docs) (for information on managing Ollama and downloading models).
